==> owncloud-8.2.2-1-any.pkg.tar.xz: usr/share/webapps/owncloud/settings/l10n/ug.js <==
OC.L10N.register(
    "settings",
    {
    "Sharing" : "ھەمبەھىر",
    "Log" : "خاتىرە",
    "Authentication error" : "سالاھىيەت دەلىللەش خاتالىقى",
    "Language changed" : "تىل ئۆزگەردى",
    "Invalid request" : "ئىناۋەتسىز ئىلتىماس",
    "Admins can't remove themself from the admin group" : "باشقۇرغۇچى ئۆزىنى باشقۇرۇش گۇرۇپپىسىدىن چىقىرىۋېتەلمەيدۇ",
    "Unable to add user to group %s" : "ئىشلەتكۈچىنى %s گۇرۇپپىغا قوشالمايدۇ",
    "Unable to remove user from group %s" : "ئىشلەتكۈچىنى %s گۇرۇپپىدىن چىقىرىۋېتەلمەيدۇ",
    "Couldn't update app." : "ئەپنى يېڭىلىيالمايدۇ.",
    "Email saved" : "تورخەت ساقلاندى",
    "All" : "ھەممىسى",
    "Please wait...." : "سەل كۈتۈڭ…",
    "Disable" : "چەكلە",
    "Enable" : "قوزغات",
    "Updating...." : "يېڭىلاۋاتىدۇ…",
    "Error while updating app" : "ئەپنى يېڭىلاۋاتقاندا خاتالىق كۆرۈلدى",
    "Updated" : "يېڭىلاندى",
    "Delete" : "ئۆچۈر",
    "Groups" : "گۇرۇپپا",
    "undo" : "يېنىۋال",
    "never" : "ھەرگىز",
    "add group" : "گۇرۇپپا قوش",
    "A valid username must be provided" : "چوقۇم ئىناۋەتلىك ئىشلەتكۈچى ئىسمىدىن بىرنى تەمىنلەش كېرەك",
    "Error creating user" : "ئىشلەتكۈچى قۇرۇۋاتقاندا خاتالىق كۆرۈلدى",
    "A valid password must be provided" : "چوقۇم ئىناۋەتلىك ئىم تەمىنلەش كېرەك",
    "__language_name__" : "ئۇيغۇرچە",
    "None" : "يوق",
    "Login" : "تىزىمغا كىرىڭ",
    "Encryption" : "شىفىرلاش",
    "Server address" : "مۇلازىمېتىر ئادرىسى",
    "Port" : "ئېغىز",
    "Log level" : "خاتىرە دەرىجىسى",
    "More" : "تېخىمۇ كۆپ",
    "Less" : "ئاز",
    "Version" : "نەشرى",
    "by" : "سەنئەتكار",
    "Forum" : "مۇنبەر",
    "Password" : "ئىم",
    "Unable to change your password" : "ئىمنى ئۆزگەرتكىلى بولمايدۇ.",
    "Current password" : "نۆۋەتتىكى ئىم",
    "New password" : "يېڭى ئىم",
    "Change password" : "ئىم ئۆزگەرت",
    "Email" : "تورخەت",
    "Your email address" : "تورخەت ئادرېسىڭىز",
    "Cancel" : "ۋاز كەچ",
    "Language" : "تىل",
    "Help translate" : "تەرجىمىگە ياردەم",
    "Username" : "ئىشلەتكۈچى ئاتى",
    "Create" : "قۇر",
    "Unlimited" : "چەكسىز",
    "Other" : "باشقا",
    "set new password" : "يېڭى ئىم تەڭشە",
    "Default" : "كۆڭۈلدىكى"
},
"nplurals=1; plural=0;");

==> owncloud-9.1.1-1-any.pkg.tar.xz: usr/share/webapps/owncloud/settings/l10n/ug.js <==
OC.L10N.register(
    "settings",
    {
    "Authentication error" : "سالاھىيەت دەلىللەش خاتالىقى",
    "Email saved" : "تورخەت ساقلاندى",
    "Sharing" : "ھەمبەھىر",
    "Log" : "خاتىرە",
    "Language changed" : "تىل ئۆزگەردى",
    "Invalid request" : "ئىناۋەتسىز ئىلتىماس",
    "Admins can't remove themself from the admin group" : "باشقۇرغۇچى ئۆزىنى باشقۇرۇش گۇرۇپپىسىدىن چىقىرىۋېتەلمەيدۇ",
    "Unable to add user to group %s" : "ئىشلەتكۈچىنى %s گۇرۇپپىغا قوشالمايدۇ",
    "Unable to remove user from group %s" : "ئىشلەتكۈچىنى %s گۇرۇپپىدىن چىقىرىۋېتەلمەيدۇ",
    "Couldn't update app." : "ئەپنى يېڭىلىيالمايدۇ.",
    "All" : "ھەممىسى",
    "Please wait...." : "سەل كۈتۈڭ…",
    "Disable" : "چەكلە",
    "Enable" : "قوزغات",
    "Updating...." : "يېڭىلاۋاتىدۇ…",
    "Error while updating app" : "ئەپنى يېڭىلاۋاتقاندا خاتالىق كۆرۈلدى",
    "Updated" : "يېڭىلاندى",
    "Delete" : "ئۆچۈر",
    "Groups" : "گۇرۇپپا",
    "undo" : "يېنىۋال",
    "never" : "ھەرگىز",
    "add group" : "گۇرۇپپا قوش",
    "A valid username must be provided" : "چوقۇم ئىناۋەتلىك ئىشلەتكۈچى ئىسمىدىن بىرنى تەمىنلەش كېرەك",
    "A valid password must be provided" : "چوقۇم ئىناۋەتلىك ئىم تەمىنلەش كېرەك",
    "__language_name__" : "ئۇيغۇرچە",
    "Unlimited" : "چەكسىز",
    "None" : "يوق",
    "Login" : "تىزىمغا كىرىڭ",
    "Encryption" : "شىفىرلاش",
    "Server address" : "مۇلازىمېتىر ئادرىسى",
    "Port" : "ئېغىز",
    "More" : "تېخىمۇ كۆپ",
    "Less" : "ئاز",
    "Version" : "نەشرى",
    "Forum" : "مۇنبەر",
    "Cancel" : "ۋاز كەچ",
    "Email" : "تورخەت",
    "Your email address" : "تورخەت ئادرېسىڭىز",
    "Password" : "ئىم",
    "Unable to change your password" : "ئىمنى ئۆزگەرتكىلى بولمايدۇ.",
    "Current password" : "نۆۋەتتىكى ئىم",
    "New password" : "يېڭى ئىم",
    "Change password" : "ئىم ئۆزگەرت",
    "Language" : "تىل",
    "Help translate" : "تەرجىمىگە ياردەم",
    "Name" : "ئاتى",
    "Username" : "ئىشلەتكۈچى ئاتى",
    "Create" : "قۇر",
    "Other" : "باشقا",
    "set new password" : "يېڭى ئىم تەڭشە",
    "Default" : "كۆڭۈلدىكى"
},
"nplurals=1; plural=0;");
